
** This file recodes variables in the ipums extract for analysis

** Keep only those aged 15 and above, for consistency with the DHS
gen include = 0
replace include = 1  if age > 14

keep if include ==1



******************************************************
** Create year of birth variable

gen birth_year = year - age
	label variable birth_year "Year of Birth"



******************************************************
* Create variables for start and end of primary school	
gen age6 = birth_year + 6
gen age13 = birth_year + 13


******************************************************
* Create colonial era indicators for secondary and primary
* use these to drop colonial era cohorts from analyses
gen colonial_primary = 0
	replace colonial_primary = 1 if age13 < 1966
	
gen colonial_secondary = 0
	replace colonial_secondary = 1 if age13 + 2 < 1965
	

******************************************************
** Create variables indicating district majorities

*tab bplke if bplke > 02000 & bplke < 03000

gen kiambu = 0
	replace kiambu = 1 if bplke==0208 | bplke==0209

gen nyeri = 0
	replace nyeri = 1 if bplke==0203 | bplke==0204 | bplke==0221
	
gen central = 0
	replace central = 1 if bplke > 0200 & bplke < 0300

gen baringo = 0
	replace baringo = 1 if bplke==0713 | bplke==0714 | bplke==0716

gen rift = 0
	replace rift = 1 if bplke > 0700 & bplke < 0800


gen kikrift = 0
	replace kikrift = 1 if bplke==0727 | bplke==0728  | bplke==0729 | bplke==0730 ///
	| bplke==0731 | bplke==0754 
	** kikuyu majorities in Nakuru and laikipia

gen kalenjin_district = 0
	replace kalenjin = 1 if rift==1 & kikrift==0
	label variable kalenjin_d "Kalenjin Majority District"

gen kikuyu_district = 0
	replace kikuyu = 1 if central==1 | kikrift==1
	label variable kikuyu_d "Kikuyu Majority District"



**** Create ethnic match variables (different lags)

gen ed_match = 0
	replace ed_match = 1 if kikuyu==1 & age13 < 1981
	replace ed_match = 1 if kalenjin==1 & age13 < 2005 & age13 > 1980
	replace ed_match = 1 if kikuyu==1 & age13 > 2004

gen one_ed_match = 0
	replace one_ed_match = 1 if kikuyu==1 & age13 < 1982
	replace one_ed_match = 1 if kalenjin==1 & age13 < 2006 & age13 > 1981
	replace one_ed_match = 1 if kikuyu==1 & age13 > 2005

gen lag_ed_match = 0
	replace lag_ed_match = 1 if kikuyu==1 & age13 < 1983
	replace lag_ed_match = 1 if kalenjin==1 & age13 < 2007 & age13 > 1982
	replace lag_ed_match = 1 if kikuyu==1 & age13 > 2006

gen three_ed_match = 0
	replace three_ed_match = 1 if kikuyu==1 & age13 < 1984
	replace three_ed_match = 1 if kalenjin==1 & age13 < 2008 & age13 > 1983
	replace three_ed_match = 1 if kikuyu==1 & age13 > 2007

gen four_ed_match = 0
	replace four_ed_match = 1 if kikuyu==1 & age13 < 1985
	replace four_ed_match = 1 if kalenjin==1 & age13 < 2009 & age13 > 1984
	replace four_ed_match = 1 if kikuyu==1 & age13 > 2008


gen secondary_match_years = 0
		replace secondary_match_years = 4 if kikuyu==1&birth_year+13< 1980 + 2
		replace secondary_match_years = 3 if kikuyu==1&birth_year+13== 1979 + 1+ 2
		replace secondary_match_years = 2 if kikuyu==1&birth_year+13==1979 + 2+ 2
		replace secondary_match_years = 1 if kikuyu==1&birth_year+13== 1979 + 3+ 2
		replace secondary_match_years = 1 if kalenjin==1&birth_year+13== 1979 + 1+ 2
		replace secondary_match_years = 2 if kalenjin==1&birth_year+13== 1979 + 2+ 2
		replace secondary_match_years = 3 if kalenjin==1&birth_year+13== 1979 + 3+ 2
		replace secondary_match_years = 4 if kalenjin==1&birth_year+13 > 1979+4+ 2 & birth_year+13< 2003+ 2
		replace secondary_match_years = 3 if kalenjin==1&birth_year+13== 2002 + 1+ 2
		replace secondary_match_years = 2 if kalenjin==1&birth_year+13== 2002 + 2+ 2
		replace secondary_match_years = 1 if kalenjin==1&birth_year+13== 2002 + 3+ 2
		replace secondary_match_years = 1 if kikuyu==1&birth_year+13== 2002 + 1+ 2
		replace secondary_match_years = 2 if kikuyu==1&birth_year+13== 2002 + 2+ 2
		replace secondary_match_years = 3 if kikuyu==1&birth_year+13== 2002 + 3+ 2
		replace secondary_match_years = 4 if kikuyu==1&birth_year+13> 2002 + 3+ 2 
		
	gen sec_match = 0 
		replace sec_match = 1 if secondary_match_years > 2		
		rename sec_match secondary_match
		label variable secondary_match "Presidential Ethnic Match During Secondary School (two year lag)"


*****************************************************************************************

** Generate primary schooling outcomes measures

gen primary_years = 0 if educke ==0 | educke==1 | educke==2
replace primary_years = 1 if educke==3
replace primary_years = 2 if educke==4
replace primary_years = 3 if educke==5
replace primary_years = 4 if educke==6
replace primary_years = 5 if educke==7
replace primary_years = 6 if educke==8
replace primary_years = 7 if educke==9
replace primary_years = 8 if educke==10
replace primary_years = 7 if educke > 10 & age6 < 1978 &  educke < 80
replace primary_years = 8 if educke > 10 & age6 > 1977 &  educke < 80


gen primary_completion = 0 if educke < 80
	replace primary_completion = 1 if educke > 9 &  educke < 80
	replace primary_completion = 1 if educke==9& age6+7 < 1985 & educke < 80

*tab educke primary_completion 

gen primary_attendance = 0 if  educke < 80
	replace primary_attend = 1 if primary_years < 0


** Generate secondary schooling outcome measures
	
	
gen secondary_attendance = 0 if educke ~=.
		replace secondary_attend = 1 if educke > 10 &  educke < 80
	
gen secondary_complete = 0 if educke ~=.
		replace secondary_complete = 1 if educke > 13 &  educke < 80
	
gen secondary_years = 0 if educke ~=. &  educke < 80
		replace secondary_years = 1 if  educke==11
		replace secondary_years = 2 if  educke==12
		replace secondary_years = 3 if  educke==13		
		replace secondary_years = 4 if  educke>13 & educke ~=. &  educke < 80

***********************************************

gen male = 0
	replace male = 1 if sex==1

gen rural = 0
	replace rural = 1 if urban ==1

*********************************
