
/*

01 October 2015

This is the Master do file that replicates all tables presented in Kramon-Posner

The calls four datasets located in the "kramon_posner_replication_files" folder:

	1) kp_dhs_rep.dta -- data for analyses that use DHS data
	2) kp_census_ipums_rep.dta -- data for analyses that use census data
		the census data file is generated in census_data_preparation.do
		one must register with IPUMS international to access the data (see README file)
	3) kp_schools_rep.dta -- data for analysis of primary school construction
	4) kp_infant_rep.dta -- data for analysis of ethnic favoritism in health

This master file calls in and runs do files located in  the "do_files" sub-directory.
The sub-directory holds an individual do file for each table

Results are outputted into the "output" sub-directory (except for Table 1)

NOTE: The tables created by the outreg2 function are not well formatted.  We
have taken the results from these tables to create the finalized tables
presented in the paper.
*/

*************************************************************************************************
** Install dependency

ssc install outreg2  // this helps with outputting the results


******************************************************************************
** Run the do files that clean and recode the IPUMS census data
* see README for instructions on how to access the census data

** do this using census_data_preparation.do


*************************************************************************************************
** Set the working directory to the kramon_posner_replication_files folder



*************************************************************************************************
**** Table 1 

use kp_dhs_rep, clear

	qui do do_files/table1
	
	* Results in Panel A and Panel B will be stored in matrices (pA and pB)
	matrix list pA // results in Panel A
	matrix list pB // results in Panel B
	matrix list pC // resuls in Panel C
	matrix list pD // results in Panel D
		

	
*************************************************************************************************
**** Table 2  - Primary education outcomes

use kp_dhs_rep, clear

	do do_files/table2


	
*************************************************************************************************
**** Table 3 - Secondary Education

use kp_dhs_rep, clear

	 do do_files/table3
	* Output is in table3.doc

****************************************************************************************
****************************************************************************************
***
*** Table 4:  Analyses in the narrower time window around the Kenyatta - Moi transition

use kp_dhs_rep, clear
	
			do do_files/table4
		* Output is in table4a.doc, table4b.doc, table4c.doc, and table4d.doc


****************************************************************************************
****************************************************************************************
***
*** Table 5:  Analyses in the narrower time window around the Moi-Kibaki transition
	
	use kp_dhs_rep, clear
		
	do do_files/table5
	* Output is in table5a.doc, table5b.doc, table5c.doc, and table5d.doc
	* Output is in table4a.doc, table4b.doc, table4c.doc, and table4d.doc
	
	
***********************************************************************************************
************************************************************************************************
** Table 6 -- Narrowing and Broadening the definition of ethnic group


	do do_files/table6
		

***********************************************************************************************
************************************************************************************************
*Table 8 - Beyond the president

	use kp_dhs_rep, clear

** Panel A -- Education Minister

		do do_files/table8a
		
		* Output is in table8a.doc


** Panel B -- Other ministers

		
	do do_files/table8b
		
		* Output is in table8b.doc

************************************************************************************************
*Table 9 - Regime Type

use kp_dhs_rep, clear

	do do_files/table9
		
		* Output is in table9.doc

************************************************************************************************
*Table 10 - School supply

	use kp_schools_rep, clear

	do do_files/table10

	* Output is in table10.doc

************************************************************************************************
*Table 11 - Improvements in well being

	use kp_infant_rep, clear
	
	do do_files/table11
	
	* output is in table11.doc


************************************************************************************************
*Table 12 -- Differences across men and women (test of the demand side)

	use kp_dhs_rep, clear

	 do do_files/table12
	
	*output is in table12.doc

	
************************************************************************************************
*Figure 1

	use kp_dhs_rep, clear

	 do do_files/figure1	
	

***********************************************************************************************
** Appendix ***********************************************************************************

********************************************************************
** Appendix A: Check robustness to lags and models

* Add appendices with secondary results (at least Table 3)
* Finish democracy appendix

use kp_dhs_rep, clear

	 do do_files/appendixA

	
***********************************************************************************************
** Appendix B: Check robustness to addition of group specific time trends

use kp_dhs_rep, clear

	do do_files/appendixB
 

************************************************************************************************
*** Appendix C:  Check robustness to different ways of clustering errors

use kp_dhs_rep, clear

	do do_files/appendixC
 

************************************************************************************************
*** Appendix D: Check that results with dichotomous DVs are robust to use of logistic regression

use kp_dhs_rep, clear

	 do do_files/appendixD
	
************************************************************************************************
******* Appendix E -- Ethnic favotirism under Kenyatta and Kibaki versus Moi

use kp_dhs_rep, clear


	do do_files/appendixE


************************************************************************************************
**** Appendix F

use kp_dhs_rep, clear

		do do_files/appendixF
